require 'sinatra/base'
require 'tilt'

class FakePaychex < Sinatra::Base
  # auth
  post %r{/auth/oauth/v2/token} do
    get_json_data 200, 'auth.json'
  end

  # workers
  get %r{/companies/.*/workers.*} do
    get_json_data 200, 'workers.json'
  end

  # workers
  get %r{/companies/.*/workers/\+d+} do
    get_json_data 200, 'workers.json'
  end

  get %r{/workers/\d+} do
    get_json_data 200, 'workers.json'
  end

  get %r{/workers/\d+/users} do
    case request.env['HTTP_ACCEPT']
    when "application/json;profile='http://api.paychex.com/profiles/users/v1'"
      get_json_data 200, 'users.json'
    else
      get_json_data 200, 'workers.json'
    end
  end

  get %r{/workers/\d+/communications} do
    get_json_data 200, 'communications.json'
  end

  get %r{/workers/\d+/communications/\d+} do
    get_json_data 200, 'communications.json'
  end

  post %r{/workers/\d+/communications} do
    get_json_data 200, 'communications.json'
  end

  put %r{/workers/\d+/communications/\d+} do
    get_json_data 200, 'communications.json'
  end

  delete %r{/workers/\d+/communications/\d+} do
    get_json_data 200, 'communications.json'
  end

  # companies

  get %r{/companies/[A-Za-z0-9]+} do
    case request.env['HTTP_ACCEPT']
    when "application/json;profile='http://api.paychex.com/profiles/company_associations/v1'"
      get_json_data 200, 'companies_associations.json'
    else
      get_json_data 200, 'companies.json'
    end
  end

  get %r{/companies} do
    get_json_data 200, 'companies.json'
  end

  get %r{/companies/[A-Za-z0-9]+/organizations+} do
    get_json_data 200, 'organizations.json'
  end

  post %r{/companies/[A-Za-z0-9]+/purchases+} do
    get_json_data 200, 'organizations.json'
  end

  # Notifications

  post %r{/notifications/\S+} do
    get_json_data 200, 'communications.json'
  end

  # Messages

  post %r{/messages} do
    get_json_data 201, 'messages.json'
  end

  get %r{/users.*} do
    get_json_data 200, 'users.json'
  end

  get %r{/users/\S/workers+} do
    get_json_data 200, 'workers.json'
  end

  # Statuses
  get %r{/status.*} do
    get_json_data 200, 'status.json'
  end

  private

  def get_json_data(response_code, file_name)
    content_type :json
    status response_code
    if file_name.nil?
      {}
    else
      File.open(File.dirname(__FILE__) + '/../fixtures/' + file_name).read
    end
  end
end
